@@ -78,7 +78,7 @@ impl KSMFileDebug {
     }
 
     fn get_info(&self) -> String {
-        match self.ksmfile.arg_section().get(0) {
+        match self.ksmfile.arg_section().arguments().nth(0) {
             Some(value) => {
                 match value {
                     KOSValue::String(s) => {
@@ -89,7 +89,7 @@ impl KSMFileDebug {
                             format!("{}", s)
                         }
                     }
-                    _ => String::from("Unknown compiler"),
+                    _ => String::from("Unknown compiler 2"),
                 }
             }
             None => String::from("Unknown compiler"),
@@ -636,7 +636,8 @@ impl KSMFileDebug {
             stream.set_color(type_color)?;
             match value {
                 kerbalobjects::KOSValue::Null => {
-                    writeln!(stream, "NULL")?;
+                    write!(stream, "NULL")?;
+                    stream.set_color(regular_color)?;
                 }
                 kerbalobjects::KOSValue::Bool(b) => {
                     write!(stream, "{:<12}", "BOOL")?;
@@ -683,6 +684,7 @@ impl KSMFileDebug {
                 }
                 kerbalobjects::KOSValue::ArgMarker => {
                     write!(stream, "{:<12}", "ARGMARKER")?;
+                    stream.set_color(regular_color)?;
                 }
                 kerbalobjects::KOSValue::ScalarInt(i) => {
                     write!(stream, "{:<12}", "SCALARINT")?;
